@@ -1,8 +1,9 @@
 package testlogger
 
 import (
-	"log/slog"
 	"testing"
+
+	"github.com/google/osv-scanner/v2/internal/cmdlogger"
 )
 
 const BeginDirectoryScan = "---Begin Directory Scan---"
@@ -12,13 +13,13 @@ const EndDirectoryScan = "---End Directory Scan---"
 // the scanning order to allow for unsorted file walks.
 func BeginDirScanMarker() {
 	if testing.Testing() {
-		slog.Info(BeginDirectoryScan)
+		cmdlogger.Infof(BeginDirectoryScan)
 	}
 }
 
 // EndDirScanMarker prints out a directory scanning marker during testing to mark the end of directory walks
 func EndDirScanMarker() {
 	if testing.Testing() {
-		slog.Info(EndDirectoryScan)
+		cmdlogger.Infof(EndDirectoryScan)
 	}
 }
