@@ -6,10 +6,10 @@ import (
 	"fmt"
 	"log/slog"
 	"maps"
+	"net/http"
 	"os"
 	"slices"
 	"sort"
-	"strings"
 	"time"
 
 	"deps.dev/util/resolve"
@@ -18,6 +18,7 @@ import (
 	"github.com/google/osv-scalibr/binary/proto"
 	"github.com/google/osv-scalibr/clients/datasource"
 	"github.com/google/osv-scalibr/clients/resolution"
+	"github.com/google/osv-scalibr/enricher/packagedeprecation"
 	"github.com/google/osv-scalibr/enricher/reachability/java"
 	"github.com/google/osv-scalibr/extractor"
 	"github.com/google/osv-scalibr/inventory"
@@ -37,7 +38,7 @@ import (
 	"github.com/google/osv-scanner/v2/internal/version"
 	"github.com/google/osv-scanner/v2/pkg/models"
 	"github.com/google/osv-scanner/v2/pkg/osvscanner/internal/imagehelpers"
-	"github.com/ossf/osv-schema/bindings/go/osvschema"
+	"github.com/ossf/osv-schema/bindings/go/osvconstants"
 	"osv.dev/bindings/go/osvdev"
 )
 
@@ -77,7 +78,14 @@ type ExperimentalScannerActions struct {
 	PluginsDisabled   []string
 	PluginsNoDefaults bool
 
+	// Currently unused.
+	// TODO(another-rex): Use or wrap this
 	StatsCollector stats.Collector
+
+	HTTPClient *http.Client
+
+	// Report deprecated packages as findings
+	FlagDeprecatedPackages bool
 }
 
 type TransitiveScanningActions struct {
@@ -99,13 +107,13 @@ type ExternalAccessors struct {
 	// DependencyClients is a map of implementations of DependencyClient
 	// for each ecosystem, the following is currently implemented:
 	// - [osvschema.EcosystemMaven] required for pomxmlnet Extractor
-	DependencyClients map[osvschema.Ecosystem]resolve.Client
+	DependencyClients map[osvconstants.Ecosystem]resolve.Client
 }
 
 // ErrNoPackagesFound for when no packages are found during a scan.
 var ErrNoPackagesFound = errors.New("no packages found in scan")
 
-// ErrVulnerabilitiesFound includes both vulnerabilities being found or license violations being found,
+// ErrVulnerabilitiesFound includes vulnerabilities, license violations, and package deprecation,
 // however, will not be raised if only uncalled vulnerabilities are found.
 var ErrVulnerabilitiesFound = errors.New("vulnerabilities found")
 
@@ -116,7 +124,7 @@ var ErrAPIFailed = errors.New("API query failed")
 func initializeExternalAccessors(actions ScannerActions) (ExternalAccessors, error) {
 	ctx := context.Background()
 	externalAccessors := ExternalAccessors{
-		DependencyClients: map[osvschema.Ecosystem]resolve.Client{},
+		DependencyClients: map[osvconstants.Ecosystem]resolve.Client{},
 	}
 	var err error
 
@@ -137,7 +145,7 @@ func initializeExternalAccessors(actions ScannerActions) (ExternalAccessors, err
 	// Online Mode
 	// -----------
 	// --- Vulnerability Matcher ---
-	externalAccessors.VulnMatcher = osvmatcher.New(5*time.Minute, "osv-scanner_scan/"+version.OSVVersion)
+	externalAccessors.VulnMatcher = osvmatcher.New(5*time.Minute, "osv-scanner_scan/"+version.OSVVersion, actions.HTTPClient)
 
 	// --- License Matcher ---
 	if len(actions.ScanLicensesAllowlist) > 0 || actions.ScanLicensesSummary {
@@ -171,13 +179,13 @@ func initializeExternalAccessors(actions ScannerActions) (ExternalAccessors, err
 	}
 
 	if !actions.NativeDataSource {
-		externalAccessors.DependencyClients[osvschema.EcosystemMaven], err = resolution.NewDepsDevClient(depsdev.DepsdevAPI, "osv-scanner_scan/"+version.OSVVersion)
+		externalAccessors.DependencyClients[osvconstants.EcosystemMaven], err = resolution.NewDepsDevClient(depsdev.DepsdevAPI, "osv-scanner_scan/"+version.OSVVersion)
 	} else {
-		externalAccessors.DependencyClients[osvschema.EcosystemMaven], err = resolution.NewMavenRegistryClient(ctx, actions.MavenRegistry, "", false)
+		externalAccessors.DependencyClients[osvconstants.EcosystemMaven], err = resolution.NewMavenRegistryClient(ctx, actions.MavenRegistry, "", false)
 	}
 
 	// We only support native registry client for PyPI.
-	externalAccessors.DependencyClients[osvschema.EcosystemPyPI] = resolution.NewPyPIRegistryClient("", "")
+	externalAccessors.DependencyClients[osvconstants.EcosystemPyPI] = resolution.NewPyPIRegistryClient("", "")
 
 	if err != nil {
 		return ExternalAccessors{}, err
@@ -232,7 +240,7 @@ func DoScan(actions ScannerActions) (models.VulnerabilityResults, error) {
 	scanResult.GenericFindings = packagesAndFindings.GenericFindings
 
 	// ----- Filtering -----
-	filterUnscannablePackages(&scanResult)
+	unscannablePackages := filterUnscannablePackages(&scanResult, actions)
 	filterIgnoredPackages(&scanResult)
 
 	// ----- Custom Overrides -----
@@ -254,6 +262,10 @@ func DoScan(actions ScannerActions) (models.VulnerabilityResults, error) {
 		}
 	}
 
+	if len(unscannablePackages) > 0 {
+		scanResult.PackageScanResults = slices.Concat(scanResult.PackageScanResults, unscannablePackages)
+	}
+
 	return finalizeScanResult(scanResult, actions)
 }
 
@@ -285,7 +297,9 @@ func DoContainerScan(actions ScannerActions) (models.VulnerabilityResults, error
 		actions,
 	)
 
-	if len(plugins) == 0 {
+	// technically having one detector enabled would also be sufficient, but we're
+	// not mentioning them to avoid confusion since they're still in their infancy
+	if countNotEnrichers(plugins) == 0 {
 		return models.VulnerabilityResults{}, errors.New("at least one extractor must be enabled")
 	}
 
@@ -293,6 +307,10 @@ func DoContainerScan(actions ScannerActions) (models.VulnerabilityResults, error
 		plugins = append(plugins, java.NewDefault())
 	}
 
+	if actions.FlagDeprecatedPackages {
+		plugins = append(plugins, packagedeprecation.New())
+	}
+
 	// --- Initialize Image To Scan ---'
 
 	// TODO: Setup context at the start of the run
@@ -342,6 +360,7 @@ func DoContainerScan(actions ScannerActions) (models.VulnerabilityResults, error
 		Plugins:           plugins,
 		Capabilities:      capabilities,
 		StoreAbsolutePath: true,
+		ExplicitPlugins:   true,
 	})
 	if err != nil {
 		return models.VulnerabilityResults{}, fmt.Errorf("failed to scan container image: %w", err)
@@ -371,7 +390,7 @@ func DoContainerScan(actions ScannerActions) (models.VulnerabilityResults, error
 	}
 
 	// ----- Filtering -----
-	filterUnscannablePackages(&scanResult)
+	unscannablePackages := filterUnscannablePackages(&scanResult, actions)
 	filterIgnoredPackages(&scanResult)
 
 	filterNonContainerRelevantPackages(&scanResult)
@@ -392,19 +411,12 @@ func DoContainerScan(actions ScannerActions) (models.VulnerabilityResults, error
 		}
 	}
 
-	// TODO: This is a set of heuristics,
-	//    - Assume that packages under /usr/ might be a OS package depending on ecosystem
-	//    - Assume python packages under dist-packages is a OS package
-	// Replace this with an actual implementation in OSV-Scalibr (potentially via full filesystem accountability).
-	for _, psr := range scanResult.PackageScanResults {
-		if (strings.HasPrefix(psr.PackageInfo.Location(), "/usr/") && psr.PackageInfo.Ecosystem().Ecosystem == osvschema.EcosystemGo) ||
-			strings.Contains(psr.PackageInfo.Location(), "dist-packages/") && psr.PackageInfo.Ecosystem().Ecosystem == osvschema.EcosystemPyPI {
-			psr.PackageInfo.AnnotationsDeprecated = append(psr.PackageInfo.AnnotationsDeprecated, extractor.InsideOSPackage)
-		}
-	}
-
 	scanResult.GenericFindings = scalibrSR.Inventory.GenericFindings
 
+	if len(unscannablePackages) > 0 {
+		scanResult.PackageScanResults = slices.Concat(scanResult.PackageScanResults, unscannablePackages)
+	}
+
 	return finalizeScanResult(scanResult, actions)
 }
 
@@ -489,8 +501,9 @@ func determineReturnErr(vulnResults models.VulnerabilityResults, showAllVulns bo
 		var vuln bool
 		onlyUnimportantVuln := true
 		var licenseViolation bool
+		deprecated := false
 		for _, vf := range vulnResults.Flatten() {
-			if vf.Vulnerability.ID != "" {
+			if vf.Vulnerability != nil && vf.Vulnerability.GetId() != "" {
 				vuln = true
 				// TODO(gongh): rewrite the logic once we support reachability analysis for container scanning.
 				if vf.GroupInfo.IsCalled() && !vf.GroupInfo.IsGroupUnimportant() {
@@ -500,13 +513,16 @@ func determineReturnErr(vulnResults models.VulnerabilityResults, showAllVulns bo
 			if len(vf.LicenseViolations) > 0 {
 				licenseViolation = true
 			}
+			if vf.Deprecated {
+				deprecated = true
+			}
 		}
 
-		if !vuln && !licenseViolation {
+		if !vuln && !licenseViolation && !deprecated {
 			return nil
 		}
 
-		onlyUnimportantVuln = onlyUnimportantVuln && vuln && !licenseViolation
+		onlyUnimportantVuln = onlyUnimportantVuln && vuln && !licenseViolation && !deprecated
 
 		// If the user didn't enable showing all vulns and we only found unimportant ones,
 		// we should return without error.
@@ -549,7 +565,7 @@ func makeVulnRequestWithMatcher(
 func overrideGoVersion(scanResults *results.ScanResults) {
 	for i, psr := range scanResults.PackageScanResults {
 		pkg := psr.PackageInfo
-		if pkg.Name() == "stdlib" && pkg.Ecosystem().Ecosystem == osvschema.EcosystemGo {
+		if pkg.Name() == "stdlib" && pkg.Ecosystem().Ecosystem == osvconstants.EcosystemGo {
 			configToUse := scanResults.ConfigManager.Get(pkg.Location())
 			if configToUse.GoVersionOverride != "" {
 				scanResults.PackageScanResults[i].PackageInfo.Package.Version = configToUse.GoVersionOverride
