@@ -10,11 +10,19 @@ import (
 
 type fileOpenedPrinter struct {
 	stats.NoopCollector
+
+	filesExtracted map[string]struct{}
 }
 
 var _ stats.Collector = &fileOpenedPrinter{}
 
-func (c fileOpenedPrinter) AfterExtractorRun(_ string, extractorstats *stats.AfterExtractorStats) {
+func (c *fileOpenedPrinter) AfterExtractorRun(_ string, extractorstats *stats.AfterExtractorStats) {
+	if c.filesExtracted == nil {
+		c.filesExtracted = make(map[string]struct{})
+	}
+
+	systemPath := filepath.Join(extractorstats.Root, filepath.FromSlash(extractorstats.Path))
+	c.filesExtracted[systemPath] = struct{}{}
 	if extractorstats.Error != nil { // Don't log scanned if error occurred
 		return
 	}
@@ -23,7 +31,7 @@ func (c fileOpenedPrinter) AfterExtractorRun(_ string, extractorstats *stats.Aft
 
 	cmdlogger.Infof(
 		"Scanned %s file and found %d %s",
-		filepath.Join(extractorstats.Root, extractorstats.Path),
+		systemPath,
 		pkgsFound,
 		output.Form(pkgsFound, "package", "packages"),
 	)
